export { make as makeHash, verify as verifyHash }
declare interface MakeOptions {
  algorithm?: 'bcrypt' | 'base64' | 'argon2'
  type?: 'argon2id' | 'argon2i' | 'argon2d'
}
declare function make(password: string, options?: MakeOptions): Promise<string>;
declare type Algorithm = 'bcrypt' | 'base64' | 'argon2'

async function verify(password: string, hash: string, algorithm?: Algorithm): Promise<boolean> {
  if (algorithm === 'argon2')
    return await argon2Verify(password, hash)
  if (algorithm === 'bcrypt')
    return await bcryptVerify(password, hash)
  if (algorithm === 'base64')
    return base64Verify(password, hash)

  throw new Error('Unsupported algorithm')
}
export declare function bcryptEncode(password: string): Promise<string>;
export declare function argon2Encode(password: string, options?: { type: 'argon2id' | 'argon2i' | 'argon2d' },): Promise<string>;
export declare function argon2Verify(password: string, hash: string): Promise<boolean>;
export declare function bcryptVerify(password: string, hash: string): Promise<boolean>;
export declare function base64Encode(password: string): string;
export declare function base64Verify(password: string, hash: string): boolean;
export declare function md5Encode(password: string): CryptoJS.lib.WordArray;